import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:module_base/module_base.dart';
import 'package:module_profile/extensions/profile/widgets/list_item.dart';

final _textBase = TextStyle(
  fontFamily: 'GraphikRBCLC',
  color: Colors.black,
  fontSize: 13,
);

class ProfileFragment extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final backgroundColor = CupertinoTheme.of(context).scaffoldBackgroundColor;

    return CupertinoPageScaffold(
      child: SingleChildScrollView(
        child: SafeArea(
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Padding(
                padding: EdgeInsets.all(16).copyWith(top: 32),
                child: Text('Меню',
                    style: _textBase.copyWith(
                      fontWeight: FontWeight.bold,
                      fontSize: 34,
                    )),
              ),
              // Account
              ExposerPoint<ExtensionItemBase>(
                name: 'profile.account',
                builder: (extensions) => _buildSection(
                      sectionName: 'УЧЕТНАЯ ЗАПИСЬ',
                      extensions: extensions,
                      backgroundColor: backgroundColor,
                    ),
              ),
              // GENERAL
              ExposerPoint<ExtensionItemBase>(
                name: 'profile.general',
                builder: (extensions) => _buildSection(
                      sectionName: 'ОБЩИЕ',
                      extensions: extensions,
                      backgroundColor: backgroundColor,
                    ),
              ),
              SizedBox(
                height: 46,
              ),
              // ADDITIONAL
              ExposerPoint<ExtensionItemBase>(
                name: 'profile.additional',
                builder: (extensions) => _buildSection(
                      extensions: extensions,
                      backgroundColor: backgroundColor,
                    ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget _buildSection(
      {String sectionName,
      @required List<ExtensionItemBase> extensions,
      @required Color backgroundColor}) {
    Widget section = _buildSectionBody(extensions, backgroundColor);

    if (sectionName != null)
      section = Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Padding(
            padding: EdgeInsets.all(16),
            child: Text(sectionName,
                style: _textBase.copyWith(
                  color: Colors.grey,
                )),
          ),
          _buildSectionBody(extensions, backgroundColor),
        ],
      );

    return section;
  }

  Widget _buildSectionBody(
          List<ExtensionItemBase> extensions, Color backgroundColor) =>
      Builder(
        builder: (context) => Container(
              color: Colors.white,
              child: Column(
                children: extensions
                    .asMap()
                    .map(
                      (index, extension) => MapEntry(
                          index,
                          _buildItem(extension.details(context),
                              backgroundColor, index < extensions.length - 1)),
                    )
                    .values
                    .toList(),
              ),
            ),
      );

  Widget _buildItem(
          ExtensionItem item, Color backgroundColor, hasBottomBorder) =>
      ListItem(
        icon: item is ExtensionIconItem
            ? Transform.scale(
                scale: item.hasDescription ? 2.5 : 1,
                child: item.icon,
              )
            : null,
        description: item.description,
        title: item.title,
        borderColor: backgroundColor,
        hasBottomBorder: hasBottomBorder,
        onTap: item.onTap,
      );
}
