import 'package:flutter/widgets.dart';
import 'package:library_icons/library_icons.dart';
import 'package:module_base/module_base.dart';

final _textBase = TextStyle(
  fontFamily: 'GraphikRBCLC',
  color: Color(0xFF000000),
);

class ListItem extends StatelessWidget {
  ListItem({
    Key key,
    this.icon,
    @required this.title,
    this.description,
    this.hasBottomBorder,
    this.borderColor,
    this.onTap,
  }) : super(key: key);

  final Widget icon;
  final String title;
  final String description;
  final Color borderColor;
  final bool hasBottomBorder;
  final OnTapHandler onTap;

  @override
  Widget build(BuildContext context) {
    final List<Widget> body = [];

    if (icon != null)
      body.add(SizedBox(
        width: _heightByDescription,
        height: _heightByDescription,
        child: icon,
      ));

    Widget text = Text(title,
        style: _textBase.copyWith(
            fontSize: 17,
            fontWeight: description != null || icon == null
                ? FontWeight.w500
                : FontWeight.normal));

    if (description != null)
      text = Column(
          mainAxisSize: MainAxisSize.max,
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            text,
            Text(description,
                style: _textBase.copyWith(
                  fontSize: 13,
                )),
          ]);

    body.add(Expanded(
      child: Container(
        height: double.infinity,
        padding: icon == null
            ? EdgeInsets.all(_paddingByDescription)
            : EdgeInsets.all(_paddingByDescription).copyWith(left: 0),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            text,
            Icon(LibraryIcons.arrow_right, color: Color(0xFFBDBDBD)),
          ],
        ),
        decoration: hasBottomBorder
            ? BoxDecoration(
                // color: Colors.red,
                border: Border(bottom: BorderSide(color: borderColor)))
            : null,
      ),
    ));

    return GestureDetector(
      child: Container(
        color: Color(0xFFFFFFFF),
        child: SizedBox(
          height: _heightByDescription,
          child: Row(
            children: body,
          ),
        ),
      ),
      onTap: () {
        if (onTap != null) onTap(context);
      },
    );
  }

  double get _paddingByDescription => description == null ? 8 : 16;

  double get _heightByDescription => description == null ? 56 : 86;
}
